Changelog
=========

* 2013-06-13 - released `hizashi-utils 0.3.1 <https://github.com/dodobas/hizashi-utils/tree/0.3.1>`_

  * Added *devserver* command
  * Added *collectstatic* command

* 2013-06-11 - released `hizashi-utils 0.3.0 <https://github.com/dodobas/hizashi-utils/tree/0.3.0>`_

  * Added *makedocs* command

* 2013-06-11 - released `hizashi-utils 0.2.2 <https://github.com/dodobas/hizashi-utils/tree/0.2.2>`_

  * Improved path handling, it's context aware
  * Updated documentation

* 2013-06-09 - released `hizashi-utils 0.2.1 <https://github.com/dodobas/hizashi-utils/tree/0.2.1>`_

  * Simple project path checks

* 2013-06-09 - released `hizashi-utils 0.2.0 <https://github.com/dodobas/hizashi-utils/tree/0.2.0>`_

  * Added *initapp* command

* 2013-06-06 - initial release

  * Added *initproject* command
